@@ -1,15 +1,11 @@
 # coding: utf-8
-# pylint: disable=W0611
 from .tables import Table
 from .columns import (BooleanColumn, Column, CheckBoxColumn, DateColumn,
                       DateTimeColumn, EmailColumn, FileColumn, LinkColumn,
-                      TemplateColumn, URLColumn, TimeColumn)
+                      RelatedLinkColumn, TemplateColumn, TimeColumn, URLColumn)
 from .config import RequestConfig
 from .utils import A
-try:
-    from .views import SingleTableMixin, SingleTableView
-except ImportError:
-    pass
+from .views import SingleTableMixin, SingleTableView
 
 
-__version__ = "1.0.7"
+__version__ = '1.2.0'
