@@ -5,7 +5,7 @@ from .datecolumn import DateColumn
 from .datetimecolumn import DateTimeColumn
 from .emailcolumn import EmailColumn
 from .filecolumn import FileColumn
-from .linkcolumn import LinkColumn
+from .linkcolumn import LinkColumn, RelatedLinkColumn
 from .templatecolumn import TemplateColumn
 from .urlcolumn import URLColumn
 from .timecolumn import TimeColumn
