@@ -1,8 +1,10 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
+
 from django.utils.safestring import mark_safe
-from django_tables2.utils import AttributeDict
-import warnings
+
+from django_tables2.utils import Accessor, AttributeDict
+
 from .base import Column, library
 
 
@@ -38,26 +40,13 @@ class CheckBoxColumn(Column):
     - *input*     -- ``<input>`` elements in both ``<td>`` and ``<th>``.
     - *th__input* -- Replaces *input* attrs in header cells.
     - *td__input* -- Replaces *input* attrs in body cells.
-    """
-    def __init__(self, attrs=None, **extra):
-        # For backwards compatibility, passing in a normal dict effectively
-        # should assign attributes to the `<input>` tag.
-        valid = set(("input", "th__input", "td__input", "th", "td", "cell"))
-        if attrs and not set(attrs) & set(valid):
-            # if none of the keys in attrs are actually valid, assume it's some
-            # old code that should be be interpreted as {"td__input": ...}
-            warnings.warn('attrs keys must be one of %s, interpreting as {"td__input": %s}'
-                          % (', '.join(valid), attrs), DeprecationWarning)
-            attrs = {"td__input": attrs}
-        # This is done for backwards compatible too, there used to be a
-        # ``header_attrs`` argument, but this has been deprecated. We'll
-        # maintain it for a while by translating it into ``head.checkbox``.
-        if "header_attrs" in extra:
-            warnings.warn('header_attrs argument is deprecated, '
-                          'use attrs={"th__input": ...} instead',
-                          DeprecationWarning)
-            attrs.setdefault('th__input', {}).update(extra.pop('header_attrs'))
 
+    To render the checkbox as checked, use the *checked* argument with a
+    accessor, boolean or callable returning boolean. If it resolves to a truthy
+    value, the checkbox will be rendered as checked.
+    """
+    def __init__(self, attrs=None, checked=None, **extra):
+        self.checked = checked
         kwargs = {'orderable': False, 'attrs': attrs}
         kwargs.update(extra)
         super(CheckBoxColumn, self).__init__(**kwargs)
@@ -70,13 +59,35 @@ class CheckBoxColumn(Column):
         attrs = AttributeDict(default, **(specific or general or {}))
         return mark_safe('<input %s/>' % attrs.as_html())
 
-    def render(self, value, bound_column):  # pylint: disable=W0221
+    def render(self, value, bound_column, record):
         default = {
             'type': 'checkbox',
             'name': bound_column.name,
             'value': value
         }
+        if self.is_checked(value, record):
+            default.update({
+                'checked': 'checked',
+            })
+
         general = self.attrs.get('input')
         specific = self.attrs.get('td__input')
         attrs = AttributeDict(default, **(specific or general or {}))
         return mark_safe('<input %s/>' % attrs.as_html())
+
+    def is_checked(self, value, record):
+        """
+        Determine if the checkbox should be checked
+        """
+        if self.checked is None:
+            return False
+        if self.checked is True:
+            return True
+
+        if callable(self.checked):
+            return bool(self.checked(value, record))
+
+        checked = Accessor(self.checked)
+        if checked in record:
+            return bool(record[checked])
+        return False
