@@ -1,6 +1,8 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
+
 from django.db import models
+
 from .base import library
 from .templatecolumn import TemplateColumn
 
@@ -10,13 +12,14 @@ class DateTimeColumn(TemplateColumn):
     """
     A column that renders datetimes in the local timezone.
 
-    :param format: format string for datetime (optional)
+    :param format: format string for datetime (optional).
+                   Note that *format* uses Django's `date` template tag syntax.
     :type  format: `unicode`
-    :param  short: if *format* is not specifid, use Django's
+    :param  short: if *format* is not specified, use Django's
                    ``SHORT_DATETIME_FORMAT``, else ``DATETIME_FORMAT``
     :type   short: `bool`
     """
-    def __init__(self, format=None, short=True, *args, **kwargs):  # pylint: disable=W0622
+    def __init__(self, format=None, short=True, *args, **kwargs):
         if format is None:
             format = 'SHORT_DATETIME_FORMAT' if short else 'DATETIME_FORMAT'
         template = '{{ value|date:"%s"|default:default }}' % format
