@@ -1,11 +1,10 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
 
-import warnings
-
 from django.core.urlresolvers import reverse
 from django.utils.html import format_html
-from django_tables2.utils import A, AttributeDict
+
+from django_tables2.utils import Accessor, AttributeDict
 
 from .base import Column, library
 
@@ -14,35 +13,39 @@ class BaseLinkColumn(Column):
     """
     The base for other columns that render links.
 
-    Adds support for an ``a`` key in *attrs** which is added to the rendered
-    ``<a href="...">`` tag.
+    :param  text: Either static text, or a callable. If set, this value will be
+                  used to render the text inside link instead of value (default).
+                  The calleble gets the record being rendered as argument.
+    :param attrs: Additional attributes for the ``<a>`` tag
     """
-    def __init__(self, attrs=None, *args, **kwargs):
-        valid = set(("a", "th", "td", "cell"))
-        if attrs and not set(attrs) & set(valid):
-            # if none of the keys in attrs are actually valid, assume it's some
-            # old code that should be be interpreted as {"a": ...}
-            warnings.warn('attrs keys must be one of %s, interpreting as {"a": %s}'
-                          % (', '.join(valid), attrs), DeprecationWarning)
-            attrs = {"a": attrs}
+    def __init__(self, attrs=None, text=None, *args, **kwargs):
         kwargs['attrs'] = attrs
+        self.text = text
         super(BaseLinkColumn, self).__init__(*args, **kwargs)
 
-    def render_link(self, uri, text, attrs=None):
+    def text_value(self, record, value):
+        if self.text is None:
+            return value
+        return self.text(record) if callable(self.text) else self.text
+
+    def render_link(self, uri, record, value, attrs=None):
         """
         Render a hyperlink.
 
-        :param   uri: URI for the hyperlink
-        :param  text: value wrapped in ``<a></a>``
-        :param attrs: ``<a>`` tag attributes
+        :param    uri: URI for the hyperlink
+        :param record: record currently being rendered
+        :param  value: value wrapped in ``<a></a>``, might be overridden by ``self.text``
+        :param  attrs: ``<a>`` tag attributes
         """
         attrs = AttributeDict(attrs if attrs is not None else
                               self.attrs.get('a', {}))
         attrs['href'] = uri
 
-        return format_html('<a {attrs}>{text}</a>',
-                           attrs=attrs.as_html(),
-                           text=text)
+        return format_html(
+            '<a {attrs}>{text}</a>',
+            attrs=attrs.as_html(),
+            text=self.text_value(record, value)
+        )
 
 
 @library.register
@@ -66,11 +69,12 @@ class LinkColumn(BaseLinkColumn):
     :param        args: See `~django.core.urlresolvers.reverse`. **
     :param      kwargs: See `~django.core.urlresolvers.reverse`. **
     :param current_app: See `~django.core.urlresolvers.reverse`.
-    :param       attrs: a `dict` of HTML attributes that are added to
-                        the rendered ``<input type="checkbox" .../>`` tag
-    :param        text: Either static text, or a callable. If set, this
-                        value will be used to render the text inside link
-                        instead of value (default)
+    :param       attrs: a `dict` of HTML attributes that are added to the
+                        rendered ``<a ...>...</a>`` tag.
+    :param        text: Either static text, or a callable. If set, this value
+                        will be used to render the text inside link instead of
+                        value (default).
+                        The calleble gets the record being rendered as argument.
 
     ** In order to create a link to a URL that relies on information in the
     current row, `.Accessor` objects can be used in the *args* or
@@ -118,58 +122,56 @@ class LinkColumn(BaseLinkColumn):
     - *a* -- ``<a>`` elements in ``<td>``.
     """
     def __init__(self, viewname=None, urlconf=None, args=None, kwargs=None,
-                 current_app=None, attrs=None, text=None, **extra):
+                 current_app=None, attrs=None, **extra):
         super(LinkColumn, self).__init__(attrs, **extra)
         self.viewname = viewname
         self.urlconf = urlconf
         self.args = args
         self.kwargs = kwargs
         self.current_app = current_app
-        self.text_value = text
 
-    def compose_url(self, record):
+    def compose_url(self, record, *args, **kwargs):
         '''Compose the url if the column is constructed with a viewname.'''
-        if isinstance(self.viewname, A):
-            viewname = self.viewname.resolve(record)
-        else:
-            viewname = self.viewname
 
-        # The following params + if statements create optional arguments to
-        # pass to Django's reverse() function.
-        params = {}
-        if self.urlconf:
-            params['urlconf'] = (self.urlconf.resolve(record)
-                                 if isinstance(self.urlconf, A)
-                                 else self.urlconf)
-        if self.args:
-            params['args'] = [a.resolve(record) if isinstance(a, A) else a
-                              for a in self.args]
-        if self.kwargs:
-            params['kwargs'] = {}
-            for key, val in self.kwargs.items():
-                # If we're dealing with an Accessor (A), resolve it, otherwise
-                # use the value verbatim.
-                params['kwargs'][str(key)] = (val.resolve(record)
-                                              if isinstance(val, A) else val)
-        if self.current_app:
-            params['current_app'] = (self.current_app.resolve(record)
-                                     if isinstance(self.current_app, A)
-                                     else self.current_app)
-
-        return reverse(viewname, **params)
-
-    def render(self, value, record, bound_column):  # pylint: disable=W0221
         if self.viewname is None:
             if not hasattr(record, 'get_absolute_url'):
                 raise TypeError('if viewname=None, record must define a get_absolute_url')
-            url = record.get_absolute_url()
-        else:
-            url = self.compose_url(record)
+            return record.get_absolute_url()
 
-        text_value = value
-        if self.text_value:
-            text_value = self.text_value
-            if callable(text_value):
-                text_value = text_value(record)
+        def resolve_if_accessor(val):
+            return val.resolve(record) if isinstance(val, Accessor) else val
 
-        return self.render_link(url, text=text_value)
+        viewname = resolve_if_accessor(self.viewname)
+
+        # Collect the optional arguments for django's reverse()
+        params = {}
+        if self.urlconf:
+            params['urlconf'] = resolve_if_accessor(self.urlconf)
+        if self.args:
+            params['args'] = [resolve_if_accessor(a) for a in self.args]
+        if self.kwargs:
+            params['kwargs'] = {key: resolve_if_accessor(val) for key, val in self.kwargs.items()}
+        if self.current_app:
+            params['current_app'] = resolve_if_accessor(self.current_app)
+
+        return reverse(viewname, **params)
+
+    def render(self, value, record, bound_column):
+        return self.render_link(
+            self.compose_url(record, bound_column),
+            record=record,
+            value=value
+        )
+
+
+@library.register
+class RelatedLinkColumn(LinkColumn):
+    '''
+    Render a link to a related object using related object's ``get_absolute_url``,
+    same parameters as ``LinkColumn``
+    '''
+
+    def compose_url(self, record, bound_column):
+        accessor = self.accessor if self.accessor else Accessor(bound_column)
+
+        return accessor.resolve(record).get_absolute_url()
