@@ -1,9 +1,12 @@
 # coding: utf-8
-import six
+
+
 from django.db import models
 from django.db.models.fields import FieldDoesNotExist
+from django.utils import six
 
-from .utils import A, getargspec
+from .columns.linkcolumn import BaseLinkColumn
+from .utils import A, AttributeDict, computed_values, signature
 
 
 class BoundRow(object):
@@ -32,31 +35,27 @@ class BoundRow(object):
         1
         <input type="checkbox" name="my_chkbox" value="2" />
 
-    Alternatively you can treat it like a list and use indexing to retrieve a
-    specific cell. It should be noted that this will raise an IndexError on
-    failure.
+    Alternatively you can use row.get_cell() to retrieve a specific cell.
 
     .. code-block:: python
 
-        >>> row[0]
+        >>> row.get_cell(0)
         1
-        >>> row[1]
+        >>> row.get_cell(1)
         u'<input type="checkbox" name="my_chkbox" value="2" />'
-        >>> row[2]
+        >>> row.get_cell(2)
         ...
         IndexError: list index out of range
 
-    Finally you can also treat it like a dictionary and use column names as the
-    keys. This will raise KeyError on failure (unlike the above indexing using
-    integers).
+    Finally you can also use the column names to retrieve a specific cell:
 
     .. code-block:: python
 
-        >>> row['a']
+        >>> row.get_cell('a')
         1
-        >>> row['b']
+        >>> row.get_cell('b')
         u'<input type="checkbox" name="my_chkbox" value="2" />'
-        >>> row['c']
+        >>> row.get_cell('c')
         ...
         KeyError: 'c'
 
@@ -75,6 +74,20 @@ class BoundRow(object):
         """The associated `.Table` object."""
         return self._table
 
+    @property
+    def attrs(self):
+        '''Return the attributes for a certain row.'''
+        cssClass = 'even' if next(self._table._counter) % 2 == 0 else 'odd'
+
+        row_attrs = computed_values(self._table.row_attrs, self._record)
+
+        if 'class' in row_attrs:
+            row_attrs['class'] += ' ' + cssClass
+        else:
+            row_attrs['class'] = cssClass
+
+        return AttributeDict(row_attrs)
+
     @property
     def record(self):
         """
@@ -95,7 +108,7 @@ class BoundRow(object):
             # is correct – it's what __getitem__ expects.
             yield value
 
-    def __getitem__(self, name):
+    def get_cell(self, name):
         """
         Returns the final rendered value for a cell in the row, given the name
         of a column.
@@ -103,55 +116,63 @@ class BoundRow(object):
         bound_column = self.table.columns[name]
 
         value = None
+        accessor = A(bound_column.accessor)
+
         # We need to take special care here to allow get_FOO_display()
         # methods on a model to be used if available. See issue #30.
-        path, _, remainder = bound_column.accessor.rpartition('.')
-        penultimate = A(path).resolve(self.record, quiet=True)
+        penultimate, remainder = accessor.penultimate(self.record)
+
         # If the penultimate is a model and the remainder is a field
         # using choices, use get_FOO_display().
         if isinstance(penultimate, models.Model):
             try:
-                field = penultimate._meta.get_field(remainder)
-                display = getattr(penultimate, 'get_%s_display' % remainder, None)
-                if getattr(field, "choices", ()) and display:
-                    value = display()
+                field = accessor.get_field(self.record)
+                display_fn = getattr(penultimate, 'get_%s_display' % remainder, None)
+                if getattr(field, 'choices', ()) and display_fn:
+                    value = display_fn()
                     remainder = None
             except FieldDoesNotExist:
                 pass
-        # Fall back to just using the original accessor (we just need
-        # to follow the remainder).
+
+        # Fall back to just using the original accessor
         if remainder:
-            value = A(remainder).resolve(penultimate, quiet=True)
+            try:
+                value = accessor.resolve(self.record)
+            except Exception:
+                # we need to account for non-field based columns (issue #257)
+                is_linkcolumn = isinstance(bound_column.column, BaseLinkColumn)
+                if is_linkcolumn and bound_column.column.text is not None:
+                    return self._call_render(bound_column)
 
         if value in bound_column.column.empty_values:
             return bound_column.default
 
-        available = {
-            'value':        value,
-            'record':       self.record,
-            'column':       bound_column.column,
+        return self._call_render(bound_column, value)
+
+    def _call_render(self, bound_column, value=None):
+        '''Call the column's render method with appropriate kwargs'''
+        kwargs = {
+            'value': value,
+            'record': self.record,
+            'column': bound_column.column,
             'bound_column': bound_column,
-            'bound_row':    self,
-            'table':        self._table,
+            'bound_row': self,
+            'table': self._table,
         }
-        expected = {}
 
-        # provide only the arguments expected by `render`
-        argspec = getargspec(bound_column.render)
-        args, varkw = argspec[0], argspec[2]
-        if varkw:
-            expected = available
-        else:
-            for key, value in available.items():
-                if key in args[1:]:
-                    expected[key] = value
+        # inspect signature of the render()-method. If the **kwargs argument is
+        # defined, pass all arguments, else provide exactly the kwargs wanted.
+        args, keywords = signature(bound_column.render)
 
-        return bound_column.render(**expected)
+        if keywords is None:
+            kwargs = {key: kwargs[key] for key in kwargs if key in args}
+
+        return bound_column.render(**kwargs)
 
     def __contains__(self, item):
         """Check by both row object and column name."""
         if isinstance(item, six.string_types):
-            return item in self.table._columns
+            return item in self.table.columns
         else:
             return item in self
 
@@ -163,7 +184,7 @@ class BoundRow(object):
         ``rendered within ``<td>``.
         """
         for column in self.table.columns:
-            yield (column, self[column.name])
+            yield (column, self.get_cell(column.name))
 
 
 class BoundRows(object):
