@@ -2,21 +2,20 @@
 from __future__ import unicode_literals
 
 import copy
-import warnings
 from collections import OrderedDict
+from itertools import count
 
-import six
-from django import VERSION
 from django.core.paginator import Paginator
 from django.db.models.fields import FieldDoesNotExist
-from django.template import RequestContext
 from django.template.loader import get_template
+from django.utils import six
+from django.utils.functional import cached_property
 
 from . import columns
 from .config import RequestConfig
 from .rows import BoundRows
 from .utils import (Accessor, AttributeDict, OrderBy, OrderByTuple, Sequence,
-                    cached_property, computed_values, segment)
+                    computed_values, segment)
 
 QUERYSET_ACCESSOR_SEPARATOR = '__'
 
@@ -33,7 +32,7 @@ class TableData(object):
         self.table = table
         # data may be a QuerySet-like objects with count() and order_by()
         if (hasattr(data, 'count') and callable(data.count) and
-            hasattr(data, 'order_by') and callable(data.order_by)):
+                hasattr(data, 'order_by') and callable(data.order_by)):
             self.queryset = data
         # otherwise it must be convertable to a list
         else:
@@ -52,8 +51,9 @@ class TableData(object):
             # Use the queryset count() method to get the length, instead of
             # loading all results into memory. This allows, for example,
             # smart paginators that use len() to perform better.
-            self._length = (self.queryset.count() if hasattr(self, 'queryset')
-                                                  else len(self.list))
+            self._length = (
+                self.queryset.count() if hasattr(self, 'queryset') else len(self.list)
+            )
         return self._length
 
     @property
@@ -141,7 +141,7 @@ class TableData(object):
         """
         The full (plural) name of the data.
 
-        This uses the same approach as `.verbose_name`.
+        This uses the same approach as `TableData.verbose_name`.
         """
         if hasattr(self, "queryset"):
             return self.queryset.model._meta.verbose_name_plural
@@ -155,7 +155,7 @@ class DeclarativeColumnsMetaclass(type):
     ``base_columns`` as well.
     """
     def __new__(mcs, name, bases, attrs):
-        attrs["_meta"] = opts = TableOptions(attrs.get("Meta", None))
+        attrs['_meta'] = opts = TableOptions(attrs.get('Meta', None))
         # extract declared columns
         cols, remainder = [], {}
         for attr_name, attr in attrs.items():
@@ -172,15 +172,15 @@ class DeclarativeColumnsMetaclass(type):
         # necessary to preserve the correct order of columns.
         parent_columns = []
         for base in bases[::-1]:
-            if hasattr(base, "base_columns"):
+            if hasattr(base, 'base_columns'):
                 parent_columns = list(base.base_columns.items()) + parent_columns
         # Start with the parent columns
-        attrs["base_columns"] = OrderedDict(parent_columns)
+        attrs['base_columns'] = OrderedDict(parent_columns)
         # Possibly add some generated columns based on a model
         if opts.model:
             extra = OrderedDict()
             # honor Table.Meta.fields, fallback to model._meta.fields
-            if opts.fields:
+            if opts.fields is not None:
                 # Each item in opts.fields is the name of a model field or a
                 # normal attribute on the model
                 for field_name in opts.fields:
@@ -194,23 +194,23 @@ class DeclarativeColumnsMetaclass(type):
             else:
                 for field in opts.model._meta.fields:
                     extra[field.name] = columns.library.column_for_field(field)
-            attrs["base_columns"].update(extra)
+            attrs['base_columns'].update(extra)
 
         # Explicit columns override both parent and generated columns
-        attrs["base_columns"].update(OrderedDict(cols))
+        attrs['base_columns'].update(OrderedDict(cols))
         # Apply any explicit exclude setting
         for exclusion in opts.exclude:
-            if exclusion in attrs["base_columns"]:
-                attrs["base_columns"].pop(exclusion)
+            if exclusion in attrs['base_columns']:
+                attrs['base_columns'].pop(exclusion)
         # Now reorder the columns based on explicit sequence
         if opts.sequence:
-            opts.sequence.expand(attrs["base_columns"].keys())
+            opts.sequence.expand(attrs['base_columns'].keys())
             # Table's sequence defaults to sequence declared in Meta
-            #attrs['_sequence'] = opts.sequence
-            attrs["base_columns"] = OrderedDict(((x, attrs["base_columns"][x]) for x in opts.sequence))
+            # attrs['_sequence'] = opts.sequence
+            attrs['base_columns'] = OrderedDict(((x, attrs['base_columns'][x]) for x in opts.sequence))
 
         # set localize on columns
-        for col_name in attrs["base_columns"].keys():
+        for col_name in attrs['base_columns'].keys():
             localize_column = None
             if col_name in opts.localize:
                 localize_column = True
@@ -219,7 +219,7 @@ class DeclarativeColumnsMetaclass(type):
                 localize_column = False
 
             if localize_column is not None:
-                attrs["base_columns"][col_name].localize = localize_column
+                attrs['base_columns'][col_name].localize = localize_column
 
         return super(DeclarativeColumnsMetaclass, mcs).__new__(mcs, name, bases, attrs)
 
@@ -233,33 +233,31 @@ class TableOptions(object):
     :param options: options for a table
     :type  options: `.Table.Meta` on a `.Table`
     """
-    # pylint: disable=R0902
     def __init__(self, options=None):
         super(TableOptions, self).__init__()
-        self.attrs = AttributeDict(getattr(options, "attrs", {}))
-        self.default = getattr(options, "default", "—")
-        self.empty_text = getattr(options, "empty_text", None)
-        self.fields = getattr(options, "fields", ())
-        self.exclude = getattr(options, "exclude", ())
-        order_by = getattr(options, "order_by", None)
+        self.attrs = AttributeDict(getattr(options, 'attrs', {}))
+        self.row_attrs = getattr(options, 'row_attrs', {})
+        self.default = getattr(options, 'default', '—')
+        self.empty_text = getattr(options, 'empty_text', None)
+        self.fields = getattr(options, 'fields', None)
+        self.exclude = getattr(options, 'exclude', ())
+        order_by = getattr(options, 'order_by', None)
         if isinstance(order_by, six.string_types):
             order_by = (order_by, )
         self.order_by = OrderByTuple(order_by) if order_by is not None else None
-        self.order_by_field = getattr(options, "order_by_field", "sort")
-        self.page_field = getattr(options, "page_field", "page")
-        self.per_page = getattr(options, "per_page", 25)
-        self.per_page_field = getattr(options, "per_page_field", "per_page")
-        self.prefix = getattr(options, "prefix", "")
-        self.show_header = getattr(options, "show_header", True)
-        self.sequence = Sequence(getattr(options, "sequence", ()))
-        if hasattr(options, "sortable"):
-            warnings.warn("`Table.Meta.sortable` is deprecated, use `orderable` instead",
-                          DeprecationWarning)
-        self.orderable = self.sortable = getattr(options, "orderable", getattr(options, "sortable", True))
-        self.model = getattr(options, "model", None)
-        self.template = getattr(options, "template", "django_tables2/table.html")
-        self.localize = getattr(options, "localize", ())
-        self.unlocalize = getattr(options, "unlocalize", ())
+        self.order_by_field = getattr(options, 'order_by_field', 'sort')
+        self.page_field = getattr(options, 'page_field', 'page')
+        self.per_page = getattr(options, 'per_page', 25)
+        self.per_page_field = getattr(options, 'per_page_field', 'per_page')
+        self.prefix = getattr(options, 'prefix', '')
+        self.show_header = getattr(options, 'show_header', True)
+        self.sequence = Sequence(getattr(options, 'sequence', ()))
+        self.orderable = getattr(options, 'orderable', True)
+        self.model = getattr(options, 'model', None)
+        self.template = getattr(options, 'template', 'django_tables2/table.html')
+        self.localize = getattr(options, 'localize', ())
+        self.unlocalize = getattr(options, 'unlocalize', ())
+
 
 class TableBase(object):
     """
@@ -350,7 +348,6 @@ class TableBase(object):
         :type: `bool`
 
 
-
     .. attribute:: prefix
 
         A prefix for querystring fields to avoid name-clashes when using
@@ -395,9 +392,9 @@ class TableBase(object):
     TableDataClass = TableData
 
     def __init__(self, data, order_by=None, orderable=None, empty_text=None,
-                 exclude=None, attrs=None, sequence=None, prefix=None,
-                 order_by_field=None, page_field=None, per_page_field=None,
-                 template=None, sortable=None, default=None, request=None,
+                 exclude=None, attrs=None, row_attrs=None, sequence=None,
+                 prefix=None, order_by_field=None, page_field=None,
+                 per_page_field=None, template=None, default=None, request=None,
                  show_header=None):
         super(TableBase, self).__init__()
         self.exclude = exclude or ()
@@ -407,14 +404,10 @@ class TableBase(object):
             default = self._meta.default
         self.default = default
         self.rows = BoundRows(data=self.data, table=self)
-        self.attrs = AttributeDict(computed_values(attrs if attrs is not None
-                                                         else self._meta.attrs))
+        attrs = computed_values(attrs if attrs is not None else self._meta.attrs)
+        self.attrs = AttributeDict(attrs)
+        self.row_attrs = AttributeDict(row_attrs or self._meta.row_attrs)
         self.empty_text = empty_text if empty_text is not None else self._meta.empty_text
-        if sortable is not None:
-            warnings.warn("`sortable` is deprecated, use `orderable` instead.",
-                          DeprecationWarning)
-            if orderable is None:
-                orderable = sortable
         self.orderable = orderable
         self.prefix = prefix
         self.order_by_field = order_by_field
@@ -436,7 +429,10 @@ class TableBase(object):
         elif self._meta.sequence:
             self._sequence = self._meta.sequence
         else:
-            self._sequence = Sequence(self._meta.fields + ('...',))
+            if self._meta.fields is not None:
+                self._sequence = Sequence(tuple(self._meta.fields) + ('...', ))
+            else:
+                self._sequence = Sequence(('...', ))
             self._sequence.expand(self.base_columns.keys())
         self.columns = columns.BoundColumns(self)
         # `None` value for order_by means no order is specified. This means we
@@ -459,19 +455,20 @@ class TableBase(object):
         if request:
             RequestConfig(request).configure(self)
 
-    def as_html(self, request=None):
+        self._counter = count()
+
+    def as_html(self, request):
         """
         Render the table to a simple HTML table, adding `request` to the context.
         """
+        # reset counter for new rendering
+        self._counter = count()
         template = get_template(self.template)
 
-        context = {'table': self}
-
-        if request:
-            if VERSION < (1, 8):
-                context = RequestContext(request, context)
-            else:
-                context['request'] = request
+        context = {
+            'table': self,
+            'request': request
+        }
 
         return template.render(context)
 
@@ -607,29 +604,21 @@ class TableBase(object):
 
     @property
     def orderable(self):
-        return (self._orderable if self._orderable is not None
-                                else self._meta.orderable)
+        if self._orderable is not None:
+            return self._orderable
+        else:
+            return self._meta.orderable
 
     @orderable.setter
     def orderable(self, value):
         self._orderable = value
 
-    @property
-    def sortable(self):
-        warnings.warn("`sortable` is deprecated, use `orderable` instead.",
-                      DeprecationWarning)
-        return self.orderable
-
-    @sortable.setter
-    def sortable(self, value):
-        warnings.warn("`sortable` is deprecated, use `orderable` instead.",
-                      DeprecationWarning)
-        self.orderable = value
-
     @property
     def template(self):
-        return (self._template if self._template is not None
-                               else self._meta.template)
+        if self._template is not None:
+            return self._template
+        else:
+            return self._meta.template
 
     @template.setter
     def template(self, value):
