@@ -1,31 +1,15 @@
 # coding: utf-8
 from __future__ import absolute_import, unicode_literals
 
-import inspect
-import warnings
+from functools import total_ordering
 from itertools import chain
 
-import six
+from django.db.models.fields import FieldDoesNotExist
+from django.utils import six
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
 
 
-def python_2_unicode_compatible(klass):
-    """
-    A decorator that defines __unicode__ and __str__ methods under Python 2.
-    Under Python 3 it does nothing.
-
-    To support Python 2 and 3 with a single code base, define a __str__ method
-    returning text and apply this decorator to the class.
-
-    Taken directly from Django.
-    """
-    if not six.PY3:
-        klass.__unicode__ = klass.__str__
-        klass.__str__ = lambda self: self.__unicode__().encode('utf-8')
-    return klass
-
-
 class Sequence(list):
     """
     Represents a column sequence, e.g. ``("first_name", "...", "last_name")``
@@ -122,9 +106,10 @@ class OrderBy(six.text_type):
         return not self.is_descending
 
 
-@python_2_unicode_compatible
+@six.python_2_unicode_compatible
 class OrderByTuple(tuple):
-    """Stores ordering as (as `.OrderBy` objects). The
+    """
+    Stores ordering as (as `.OrderBy` objects). The
     `~django_tables2.tables.Table.order_by` property is always converted
     to an `.OrderByTuple` object.
 
@@ -251,39 +236,6 @@ class OrderByTuple(tuple):
                 return False
         return Comparator
 
-    @property
-    def cmp(self):
-        """
-        Return a function for use with `list.sort` that implements this
-        object's ordering. This is used to sort non-`.QuerySet` based
-        :term:`table data`.
-
-        :rtype: function
-        """
-        warnings.warn('`cmp` is deprecated, use `key` instead.',
-                      DeprecationWarning)
-
-        # pylint: disable=C0103
-        def _cmp(a, b):
-            for accessor, reverse in instructions:
-                x = accessor.resolve(a)
-                y = accessor.resolve(b)
-                try:
-                    res = cmp(x, y)
-                except TypeError:
-                    res = cmp((repr(type(x)), id(type(x)), x),
-                              (repr(type(y)), id(type(y)), y))
-                if res != 0:
-                    return -res if reverse else res
-            return 0
-        instructions = []
-        for order_by in self:
-            if order_by.startswith('-'):
-                instructions.append((Accessor(order_by[1:]), True))
-            else:
-                instructions.append((Accessor(order_by), False))
-        return _cmp
-
     def get(self, key, fallback):
         """
         Identical to __getitem__, but supports fallback value.
@@ -371,8 +323,8 @@ class Accessor(str):
                                 TypeError,   # unsubscriptable object
                                 ):
                             raise ValueError('Failed lookup for key [%s] in %r'
-                                             ', when resolving the accessor %s'
-                                              % (bit, current, self))
+                                             ', when resolving the accessor %s' % (bit, current, self)
+                                             )
                 if callable(current):
                     if safe and getattr(current, 'alters_data', False):
                         raise ValueError('refusing to call %s() because `.alters_data = True`'
@@ -395,9 +347,39 @@ class Accessor(str):
             return ()
         return self.split(self.SEPARATOR)
 
+    def get_field(self, model):
+        '''Return the django model field for model in context, following relations'''
+        if not hasattr(model, '_meta'):
+            return
+
+        field = None
+        for bit in self.bits:
+            try:
+                field = model._meta.get_field(bit)
+            except FieldDoesNotExist:
+                break
+            if hasattr(field, 'rel') and hasattr(field.rel, 'to'):
+                model = field.rel.to
+                continue
+
+        return field
+
+    def penultimate(self, context, quiet=True):
+        '''
+        Split the accessor on the right-most dot '.', return a tuple with:
+         - the resolved left part.
+         - the remainder
+
+        >>> Accessor('a.b.c').penultimate({'a': {'a': 1, 'b': {'c': 2, 'd': 4}}})
+        ({'c': 2, 'd': 4}, 'c')
+        '''
+        path, _, remainder = self.rpartition('.')
+        return A(path).resolve(context, quiet=quiet), remainder
+
 
 A = Accessor  # alias
 
+
 class AttributeDict(dict):
     """
     A wrapper around `dict` that knows how to render itself as HTML
@@ -448,7 +430,7 @@ def segment(sequence, aliases):
     for alias, parts in aliases.items():
         variants = {
             # alias: order by tuple
-            alias:  OrderByTuple(parts),
+            alias: OrderByTuple(parts),
             OrderBy(alias).opposite: OrderByTuple(parts).opposite,
         }
         for valias, vparts in variants.items():
@@ -465,65 +447,50 @@ def segment(sequence, aliases):
                     yield tuple([valias])
 
 
-class cached_property(object):  # pylint: disable=C0103
+def signature(fn):
+    '''
+    Returns a tuple containing:
+     - the arguments (positional or keyword)
+     - the name of the ** kwarg catch all.
+
+    The self-argument for methods is always removed.
+    '''
+    import inspect
+    # getargspec is Deprecated since version 3.0, so if not PY2, use the new
+    # inspect api.
+
+    if six.PY2:
+        argspec = inspect.getargspec(fn)
+        args = argspec.args
+        return (
+            tuple(args[1:] if args[0] == 'self' else args),
+            argspec.keywords
+        )
+    else:
+        signature = inspect.signature(fn)
+
+        args = []
+        keywords = None
+        for arg in signature.parameters.values():
+            if arg.kind == arg.VAR_KEYWORD:
+                keywords = arg.name
+            elif arg.kind == arg.VAR_POSITIONAL:
+                # skip *args catch-all
+                continue
+            else:
+                args.append(arg.name)
+
+        return tuple(args), keywords
+
+
+def computed_values(d, *args, **kwargs):
     """
-    Decorator that creates converts a method with a single
-    self argument into a property cached on the instance.
-
-    Taken directly from Django 1.4.
-    """
-    def __init__(self, func):
-        from functools import wraps
-        wraps(func)(self)
-        self.func = func
-
-    def __get__(self, instance, cls):
-        res = instance.__dict__[self.func.__name__] = self.func(instance)
-        return res
-
-
-funcs = (name for name in ('getfullargspec', 'getargspec')
-                       if hasattr(inspect, name))
-getargspec = getattr(inspect, next(funcs))
-del funcs
-
-
-def total_ordering(cls):
-    """Class decorator that fills in missing ordering methods"""
-    convert = {
-        '__lt__': [('__gt__', lambda self, other: not (self < other or self == other)),
-                   ('__le__', lambda self, other: self < other or self == other),
-                   ('__ge__', lambda self, other: not self < other)],
-        '__le__': [('__ge__', lambda self, other: not self <= other or self == other),
-                   ('__lt__', lambda self, other: self <= other and not self == other),
-                   ('__gt__', lambda self, other: not self <= other)],
-        '__gt__': [('__lt__', lambda self, other: not (self > other or self == other)),
-                   ('__ge__', lambda self, other: self > other or self == other),
-                   ('__le__', lambda self, other: not self > other)],
-        '__ge__': [('__le__', lambda self, other: (not self >= other) or self == other),
-                   ('__gt__', lambda self, other: self >= other and not self == other),
-                   ('__lt__', lambda self, other: not self >= other)]
-    }
-    roots = set(dir(cls)) & set(convert)
-    if not roots:
-        raise ValueError('must define at least one ordering operation: < > <= >=')
-    root = max(roots)       # prefer __lt__ to __le__ to __gt__ to __ge__
-    for opname, opfunc in convert[root]:
-        if opname not in roots:
-            opfunc.__name__ = str(opname)  # Py2 requires non-unicode, Py3 requires unicode.
-            opfunc.__doc__ = getattr(int, opname).__doc__
-            setattr(cls, opname, opfunc)
-    return cls
-
-
-def computed_values(d):
-    """
-    Computes a new `dict` that has callable values replaced with the return values.
+    Returns a new `dict` that has callable values replaced with the return values.
 
     Simple example:
 
-        >>> compute_values({"foo": lambda: "bar"})
-        {"foo": "bar"}
+        >>> compute_values({'foo': lambda: 'bar'})
+        {'foo': 'bar'}
 
     Arbitrarily deep structures are supported. The logic is as follows:
 
@@ -534,25 +501,25 @@ def computed_values(d):
 
         >>> def parents():
         ...     return {
-        ...         "father": lambda: "Foo",
-        ...         "mother": "Bar"
+        ...         'father': lambda: 'Foo',
+        ...         'mother': 'Bar'
         ...      }
         ...
         >>> a = {
-        ...     "name": "Brad",
-        ...     "parents": parents
+        ...     'name': 'Brad',
+        ...     'parents': parents
         ... }
         ...
         >>> computed_values(a)
-        {"name": "Brad", "parents": {"father": "Foo", "mother": "Bar"}}
+        {'name': 'Brad', 'parents': {'father': 'Foo', 'mother': 'Bar'}}
 
     :rtype: dict
     """
     result = {}
     for k, v in six.iteritems(d):
         if callable(v):
-            v = v()
+            v = v(*args, **kwargs)
         if isinstance(v, dict):
-            v = computed_values(v)
+            v = computed_values(v, *args, **kwargs)
         result[k] = v
     return result
