@@ -41,9 +41,16 @@ class SingleTableMixin(object):
         options = {}
         table_class = self.get_table_class()
         table = table_class(self.get_table_data(), **kwargs)
-        paginate = self.get_table_pagination()  # pylint: disable=E1102
+
+        paginate = self.get_table_pagination(table)
         if paginate is not None:
             options['paginate'] = paginate
+
+        elif self.paginate_by is not None:
+            # Since ListView knows the concept paginate_by, we use that if no
+            # other pagination is configured.
+            options['paginate'] = {'per_page': self.paginate_by}
+
         RequestConfig(self.request, **options).configure(table)
         return table
 
@@ -53,31 +60,39 @@ class SingleTableMixin(object):
         """
         if self.table_class:
             return self.table_class
-        raise ImproperlyConfigured("A table class was not specified. Define "
-                                   "%(cls)s.table_class"
-                                   % {"cls": type(self).__name__})
+        klass = type(self).__name__
+        raise ImproperlyConfigured(
+            'A table class was not specified. Define {}.table_class'.format(klass)
+        )
 
     def get_context_table_name(self, table):
         """
         Get the name to use for the table's template variable.
         """
-        return self.context_table_name or "table"
+        return self.context_table_name or 'table'
 
     def get_table_data(self):
         """
         Return the table data that should be used to populate the rows.
         """
-        if self.table_data:
+        if self.table_data is not None:
             return self.table_data
-        elif hasattr(self, "object_list"):
+        elif hasattr(self, 'object_list'):
             return self.object_list
-        elif hasattr(self, "get_queryset"):
-            return self.get_queryset()
-        raise ImproperlyConfigured("Table data was not specified. Define "
-                                   "%(cls)s.table_data"
-                                   % {"cls": type(self).__name__})
 
-    def get_table_pagination(self):
+        # it seems this is never going to happen because django wil raise
+        # ImproperlyConfigured if no model is defined and
+        # SingleTableMixin.get_table_class will raise if no table_data was specified...
+        # TODO: consider removing
+        elif hasattr(self, 'get_queryset'):
+            return self.get_queryset()
+
+        klass = type(self).__name__
+        raise ImproperlyConfigured(
+            'Table data was not specified. Define {}.table_data'.format(klass)
+        )
+
+    def get_table_pagination(self, table):
         """
         Returns pagination options: True for standard pagination (default),
         False for no pagination, and a dictionary for custom pagination.
