@@ -1,5 +1,6 @@
 # coding: utf-8
 from __future__ import unicode_literals
+
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
@@ -19,6 +20,9 @@ class Country(models.Model):
     def __unicode__(self):
         return self.name
 
+    def get_absolute_url(self):
+        return 'country/%d' % self.pk
+
     @property
     def summary(self):
         return "%s (pop. %s)" % (self.name, self.population)
@@ -27,6 +31,8 @@ class Country(models.Model):
 class Person(models.Model):
     name = models.CharField(max_length=200, verbose_name="full name")
 
+    country = models.ForeignKey(Country, null=True)
+
     class Meta:
         verbose_name_plural = "people"
 
