@@ -1,17 +1,16 @@
 # coding: utf-8
-# pylint: disable=R0912,E0102
 from __future__ import unicode_literals
 
-import django_tables2 as tables
+import pytest
 from django.core.urlresolvers import reverse
 from django.template import Context, Template
 from django.utils.html import mark_safe
+
+import django_tables2 as tables
 from django_tables2 import A
 
-import pytest
-
-from ..app.models import Person
-from ..utils import attrs, build_request, warns
+from ..app.models import Occupation, Person
+from ..utils import attrs, build_request
 
 
 def test_unicode():
@@ -24,7 +23,7 @@ def test_unicode():
     dataset = [
         {'pk': 1, 'first_name': 'Brädley', 'last_name': '∆yers'},
         {'pk': 2, 'first_name': 'Chr…s', 'last_name': 'DÒble'},
-        ]
+    ]
 
     table = UnicodeTable(dataset)
     request = build_request('/some-url/')
@@ -40,35 +39,42 @@ def test_unicode():
 def test_link_text_custom_value():
     class CustomLinkTable(tables.Table):
         first_name = tables.LinkColumn('person', text='foo::bar', args=[A('pk')])
-        last_name = tables.LinkColumn('person', text=lambda row: '%s %s' % (row['last_name'], row['first_name']), args=[A('pk')])
+        last_name = tables.LinkColumn(
+            'person',
+            text=lambda row: '%s %s' % (row['last_name'], row['first_name']),
+            args=[A('pk')]
+        )
 
     dataset = [
         {'pk': 1, 'first_name': 'John', 'last_name': 'Doe'}
     ]
 
     table = CustomLinkTable(dataset)
-    request = build_request('/some-url/')
-    template = Template('{% load django_tables2 %}{% render_table table %}')
-    html = template.render(Context({'request': request, 'table': table}))
+    html = table.as_html(build_request('/some-url/'))
 
     assert 'foo::bar' in html
     assert 'Doe John' in html
 
 
-def test_link_text_excaping():
+def test_link_text_escaping():
     class CustomLinkTable(tables.Table):
-        last_name = tables.LinkColumn('person', text=mark_safe('<i class="glyphicon glyphicon-pencil"></i>'), args=[A('pk')])
+        editlink = tables.LinkColumn(
+            'person',
+            text=mark_safe('edit'),
+            args=[A('pk')]
+        )
 
     dataset = [
         {'pk': 1, 'first_name': 'John', 'last_name': 'Doe'}
     ]
 
     table = CustomLinkTable(dataset)
-    request = build_request('/some-url/')
-    template = Template('{% load django_tables2 %}{% render_table table %}')
-    html = template.render(Context({'request': request, 'table': table}))
+    html = table.as_html(build_request('/some-url/'))
 
-    assert '><i class="glyphicon glyphicon-pencil"></i></a>' in html
+    expected = '<td class="editlink"><a href="{}">edit</a></td>'.format(
+        reverse('person', args=(1, ))
+    )
+    assert expected in html
 
 
 @pytest.mark.django_db
@@ -80,48 +86,57 @@ def test_null_foreign_key():
 
     Person.objects.create(first_name='bradley', last_name='ayers')
 
-    request = build_request()
     table = PersonTable(Person.objects.all())
-    table.as_html(request)
+    html = table.as_html(build_request())
+
+    assert '<td class="occupation">—</td>' in html
+
+
+@pytest.mark.django_db
+def test_linkcolumn_non_field_based():
+    '''Test for issue 257, non-field based columns'''
+    class Table(tables.Table):
+        first_name = tables.Column()
+        delete_link = tables.LinkColumn('person_delete', text='delete', kwargs={'pk': tables.A('id')})
+
+    willem = Person.objects.create(first_name='Willem', last_name='Wever')
+
+    html = Table(Person.objects.all()).as_html(build_request())
+
+    expected = '<td class="delete_link"><a href="{}">delete</a></td>'.format(
+        reverse('person_delete', kwargs={'pk': willem.pk})
+    )
+    assert expected in html
 
 
 def test_kwargs():
     class PersonTable(tables.Table):
-        a = tables.LinkColumn('occupation', kwargs={"pk": A('a')})
+        a = tables.LinkColumn('occupation', kwargs={'pk': A('a')})
 
     request = build_request('/')
-    html = PersonTable([{"a": 0}, {"a": 1}]).as_html(request)
-    assert reverse("occupation", kwargs={"pk": 0}) in html
-    assert reverse("occupation", kwargs={"pk": 1}) in html
+    html = PersonTable([{'a': 0}, {'a': 1}]).as_html(request)
+    assert reverse('occupation', kwargs={'pk': 0}) in html
+    assert reverse('occupation', kwargs={'pk': 1}) in html
 
 
 def test_html_escape_value():
     class PersonTable(tables.Table):
-        name = tables.LinkColumn("escaping", kwargs={"pk": A("pk")})
+        name = tables.LinkColumn('escaping', kwargs={'pk': A('pk')})
 
-    table = PersonTable([{"name": "<brad>", "pk": 1}])
-    assert table.rows[0]["name"] == '<a href="/&amp;&#39;%22/1/">&lt;brad&gt;</a>'
-
-
-def test_old_style_attrs_should_still_work():
-    with warns(DeprecationWarning):
-        class TestTable(tables.Table):
-            col = tables.LinkColumn('occupation', kwargs={"pk": A('col')},
-                                    attrs={"title": "Occupation Title"})
-
-    table = TestTable([{"col": 0}])
-    assert attrs(table.rows[0]["col"]) == {"href": reverse("occupation", kwargs={"pk": 0}),
-                                           "title": "Occupation Title"}
+    table = PersonTable([{'name': '<brad>', 'pk': 1}])
+    assert table.rows[0].get_cell('name') == '<a href="/&amp;&#39;%22/1/">&lt;brad&gt;</a>'
 
 
 def test_a_attrs_should_be_supported():
     class TestTable(tables.Table):
         col = tables.LinkColumn('occupation', kwargs={'pk': A('col')},
-                                attrs={"a": {"title": "Occupation Title"}})
+                                attrs={'a': {'title': 'Occupation Title'}})
 
     table = TestTable([{'col': 0}])
-    assert attrs(table.rows[0]['col']) == {'href': reverse('occupation', kwargs={'pk': 0}),
-                                           'title': 'Occupation Title'}
+    assert attrs(table.rows[0].get_cell('col')) == {
+        'href': reverse('occupation', kwargs={'pk': 0}),
+        'title': 'Occupation Title'
+    }
 
 
 def test_defaults():
@@ -129,7 +144,7 @@ def test_defaults():
         link = tables.LinkColumn('occupation', kwargs={'pk': 1}, default='xyz')
 
     table = Table([{}])
-    assert table.rows[0]['link'] == 'xyz'
+    assert table.rows[0].get_cell('link') == 'xyz'
 
 
 @pytest.mark.django_db
@@ -142,7 +157,7 @@ def test_get_absolute_url():
     table = PersonTable(Person.objects.all())
 
     expected = '<a href="/people/%d/">Waagmeester</a>' % person.pk
-    assert table.rows[0]['last_name'] == expected
+    assert table.rows[0].get_cell('last_name') == expected
 
 
 def test_get_absolute_url_not_defined():
@@ -156,3 +171,18 @@ def test_get_absolute_url_not_defined():
 
     with pytest.raises(TypeError):
         table.as_html(build_request('/'))
+
+
+@pytest.mark.django_db
+def test_RelatedLinkColumn():
+    carpenter = Occupation.objects.create(name='Carpenter')
+    Person.objects.create(first_name='Bob', last_name='Builder', occupation=carpenter)
+
+    class Table(tables.Table):
+        first_name = tables.LinkColumn()
+        last_name = tables.Column()
+        occupation = tables.RelatedLinkColumn()
+
+    table = Table(Person.objects.all())
+
+    assert table.rows[0].get_cell('occupation') == '<a href="/occupations/%d/">Carpenter</a>' % carpenter.pk
