@@ -5,14 +5,14 @@ from __future__ import absolute_import, unicode_literals
 import copy
 import itertools
 
-import pytest
-import six
 from django.core.paginator import EmptyPage, PageNotAnInteger, Paginator
+from django.utils import six
 
 import django_tables2 as tables
+import pytest
 from django_tables2.tables import DeclarativeColumnsMetaclass
 
-from .utils import build_request, warns
+from .utils import build_request
 
 request = build_request('/')
 
@@ -35,6 +35,21 @@ MEMORY_DATA = [
 ]
 
 
+def test_column_named_items():
+    '''
+    A column named items must not make the table fail
+    https://github.com/bradleyayers/django-tables2/issues/316
+    '''
+    class ItemsTable(tables.Table):
+        items = tables.Column()
+
+    table = ItemsTable([{'items': 123}, {'items': 2345}])
+
+    html = table.as_html(request)
+    assert '123' in html
+    assert '2345' in html
+
+
 def test_declarations():
     """Test defining tables by declaration."""
     class GeoAreaTable(tables.Table):
@@ -166,7 +181,6 @@ def test_should_support_tuple_data_source():
     assert len(table.rows) == 2
 
 
-@pytest.mark.skipif(six.PY3, reason="Haystack requires Python 2.x")
 def test_should_support_haystack_data_source():
     from haystack.query import SearchQuerySet
 
@@ -191,6 +205,7 @@ def test_data_validation():
     class Ok:
         def __len__(self):
             return 1
+
         def __getitem__(self, pos):
             if pos != 0:
                 raise IndexError()
@@ -205,8 +220,8 @@ def test_ordering():
     assert ('alpha', ) == OrderedTable([], order_by=None).order_by == OrderedTable([]).order_by
 
     # values of order_by are wrapped in tuples before being returned
-    assert OrderedTable([], order_by='alpha').order_by   == ('alpha', )
-    assert OrderedTable([], order_by=('beta',)).order_by == ('beta', )
+    assert OrderedTable([], order_by='alpha').order_by == ('alpha', )
+    assert OrderedTable([], order_by=('beta', )).order_by == ('beta', )
 
     table = OrderedTable([])
     table.order_by = []
@@ -227,18 +242,18 @@ def test_ordering():
 
     table = OrderedTable([])
     table.order_by = 'alpha'
-    assert ('alpha', ) == OrderedTable([], order_by='alpha').order_by  == table.order_by
+    assert ('alpha', ) == OrderedTable([], order_by='alpha').order_by == table.order_by
 
     # let's check the data
     table = OrderedTable(MEMORY_DATA, order_by='beta')
-    assert 3 == table.rows[0]['i']
+    assert 3 == table.rows[0].get_cell('i')
 
     table = OrderedTable(MEMORY_DATA, order_by='-beta')
-    assert 1 == table.rows[0]['i']
+    assert 1 == table.rows[0].get_cell('i')
 
     # allow fallback to Table.Meta.order_by
     table = OrderedTable(MEMORY_DATA)
-    assert 1 == table.rows[0]['i']
+    assert 1 == table.rows[0].get_cell('i')
 
     # column's can't be ordered if they're not allowed to be
     class TestTable2(tables.Table):
@@ -268,20 +283,6 @@ def test_ordering():
     table = TestTable3([], orderable=True, order_by='b')
     assert table.order_by == ('b', )
 
-    with warns(DeprecationWarning) as captured:
-        tables.Column(sortable=True)
-        tables.Column(sortable=False)
-
-        class TestTable4(tables.Table):
-            class Meta:
-                sortable = True
-
-        class TestTable4(tables.Table):
-            class Meta:
-                sortable = False
-
-    assert len(captured) == 4
-
 
 def test_ordering_different_types():
     from datetime import datetime
@@ -293,25 +294,24 @@ def test_ordering_different_types():
     ]
 
     table = OrderedTable(data)
-    assert "—" == table.rows[0]['alpha']
+    assert "—" == table.rows[0].get_cell('alpha')
 
     table = OrderedTable(data, order_by='i')
     if six.PY3:
-        assert {} == table.rows[0]['i']
+        assert {} == table.rows[0].get_cell('i')
     else:
-        assert 1 == table.rows[0]['i']
-
+        assert 1 == table.rows[0].get_cell('i')
 
     table = OrderedTable(data, order_by='beta')
-    assert [] == table.rows[0]['beta']
+    assert [] == table.rows[0].get_cell('beta')
 
 
 def test_multi_column_ordering():
-    brad   = {"first_name": "Bradley", "last_name": "Ayers"}
-    brad2  = {"first_name": "Bradley", "last_name": "Fake"}
-    chris  = {"first_name": "Chris",   "last_name": "Doble"}
-    davina = {"first_name": "Davina",  "last_name": "Adisusila"}
-    ross   = {"first_name": "Ross",    "last_name": "Ayers"}
+    brad = {'first_name': 'Bradley', 'last_name': 'Ayers'}
+    brad2 = {'first_name': 'Bradley', 'last_name': 'Fake'}
+    chris = {'first_name': 'Chris', 'last_name': 'Doble'}
+    davina = {'first_name': 'Davina', 'last_name': 'Adisusila'}
+    ross = {'first_name': 'Ross', 'last_name': 'Ayers'}
 
     people = [brad, brad2, chris, davina, ross]
 
@@ -319,25 +319,25 @@ def test_multi_column_ordering():
         first_name = tables.Column()
         last_name = tables.Column()
 
-    table = PersonTable(people, order_by=("first_name", "last_name"))
+    table = PersonTable(people, order_by=('first_name', 'last_name'))
     assert [brad, brad2, chris, davina, ross] == [r.record for r in table.rows]
 
-    table = PersonTable(people, order_by=("first_name", "-last_name"))
+    table = PersonTable(people, order_by=('first_name', '-last_name'))
     assert [brad2, brad, chris, davina, ross] == [r.record for r in table.rows]
 
     # let's try column order_by using multiple keys
     class PersonTable(tables.Table):
-        name = tables.Column(order_by=("first_name", "last_name"))
+        name = tables.Column(order_by=('first_name', 'last_name'))
 
     # add 'name' key for each person.
     for person in people:
-        person['name'] = "{p[first_name]} {p[last_name]}".format(p=person)
-    assert brad['name'] == "Bradley Ayers"
+        person['name'] = '{p[first_name]} {p[last_name]}'.format(p=person)
+    assert brad['name'] == 'Bradley Ayers'
 
-    table = PersonTable(people, order_by="name")
+    table = PersonTable(people, order_by='name')
     assert [brad, brad2, chris, davina, ross] == [r.record for r in table.rows]
 
-    table = PersonTable(people, order_by="-name")
+    table = PersonTable(people, order_by='-name')
     assert [ross, davina, chris, brad2, brad] == [r.record for r in table.rows]
 
 
@@ -355,9 +355,9 @@ def test_column_accessor():
         col1 = tables.Column(accessor='alpha.upper.isupper')
         col2 = tables.Column(accessor='alpha.upper')
     table = SimpleTable(MEMORY_DATA)
-    row = table.rows[0]
-    assert row['col1'] is True
-    assert row['col2'] == 'B'
+
+    assert table.rows[0].get_cell('col1') is True
+    assert table.rows[0].get_cell('col2') == 'B'
 
 
 def test_exclude_columns():
@@ -368,29 +368,30 @@ def test_exclude_columns():
     columns originally.
     """
     # Table(..., exclude=...)
-    table = UnorderedTable([], exclude=("i"))
-    assert [c.name for c in table.columns] == ["alpha", "beta"]
+    table = UnorderedTable([], exclude=('i'))
+    assert [c.name for c in table.columns] == ['alpha', 'beta']
 
     # Table.Meta: exclude=...
     class PartialTable(UnorderedTable):
         class Meta:
-            exclude = ("alpha", )
+            exclude = ('alpha', )
     table = PartialTable([])
-    assert [c.name for c in table.columns] == ["i", "beta"]
+    assert [c.name for c in table.columns] == ['i', 'beta']
 
     # Inheritence -- exclude in parent, add in child
     class AddonTable(PartialTable):
         added = tables.Column()
     table = AddonTable([])
-    assert [c.name for c in table.columns] == ["i", "beta", "added"]
+    assert [c.name for c in table.columns] == ['i', 'beta', 'added']
 
     # Inheritence -- exclude in child
     class ExcludeTable(UnorderedTable):
         added = tables.Column()
+
         class Meta:
-            exclude = ("beta", )
+            exclude = ('beta', )
     table = ExcludeTable([])
-    assert [c.name for c in table.columns] == ["i", "alpha", "added"]
+    assert [c.name for c in table.columns] == ['i', 'alpha', 'added']
 
 
 def test_table_exclude_property_should_override_constructor_argument():
@@ -477,84 +478,84 @@ def test_prefix():
         name = tables.Column()
 
         class Meta:
-            prefix = "x"
+            prefix = 'x'
 
-    assert "x" == TableA([]).prefix
+    assert 'x' == TableA([]).prefix
 
     class TableB(tables.Table):
         name = tables.Column()
 
-    assert "" == TableB([]).prefix
-    assert "x" == TableB([], prefix="x").prefix
+    assert '' == TableB([]).prefix
+    assert 'x' == TableB([], prefix='x').prefix
 
     table = TableB([])
-    table.prefix = "x"
-    assert "x" == table.prefix
+    table.prefix = 'x'
+    assert 'x' == table.prefix
 
 
 def test_field_names():
     class TableA(tables.Table):
         class Meta:
-            order_by_field = "abc"
-            page_field = "def"
-            per_page_field = "ghi"
+            order_by_field = 'abc'
+            page_field = 'def'
+            per_page_field = 'ghi'
 
     table = TableA([])
-    assert "abc" == table.order_by_field
-    assert "def" == table.page_field
-    assert "ghi" == table.per_page_field
+    assert 'abc' == table.order_by_field
+    assert 'def' == table.page_field
+    assert 'ghi' == table.per_page_field
 
 
 def test_field_names_with_prefix():
     class TableA(tables.Table):
         class Meta:
-            order_by_field = "sort"
-            page_field = "page"
-            per_page_field = "per_page"
-            prefix = "1-"
+            order_by_field = 'sort'
+            page_field = 'page'
+            per_page_field = 'per_page'
+            prefix = '1-'
 
     table = TableA([])
-    assert "1-sort" == table.prefixed_order_by_field
-    assert "1-page" == table.prefixed_page_field
-    assert "1-per_page" == table.prefixed_per_page_field
+    assert '1-sort' == table.prefixed_order_by_field
+    assert '1-page' == table.prefixed_page_field
+    assert '1-per_page' == table.prefixed_per_page_field
 
     class TableB(tables.Table):
         class Meta:
-            order_by_field = "sort"
-            page_field = "page"
-            per_page_field = "per_page"
+            order_by_field = 'sort'
+            page_field = 'page'
+            per_page_field = 'per_page'
 
-    table = TableB([], prefix="1-")
-    assert "1-sort" == table.prefixed_order_by_field
-    assert "1-page" == table.prefixed_page_field
-    assert "1-per_page" == table.prefixed_per_page_field
+    table = TableB([], prefix='1-')
+    assert '1-sort' == table.prefixed_order_by_field
+    assert '1-page' == table.prefixed_page_field
+    assert '1-per_page' == table.prefixed_per_page_field
 
     table = TableB([])
-    table.prefix = "1-"
-    assert "1-sort" == table.prefixed_order_by_field
-    assert "1-page" == table.prefixed_page_field
-    assert "1-per_page" == table.prefixed_per_page_field
+    table.prefix = '1-'
+    assert '1-sort' == table.prefixed_order_by_field
+    assert '1-page' == table.prefixed_page_field
+    assert '1-per_page' == table.prefixed_per_page_field
 
 
 def test_should_support_a_template_to_be_specified():
     class ConstructorSpecifiedTemplateTable(tables.Table):
         name = tables.Column()
 
-    table = ConstructorSpecifiedTemplateTable([], template="dummy.html")
-    assert table.template == "dummy.html"
+    table = ConstructorSpecifiedTemplateTable([], template='dummy.html')
+    assert table.template == 'dummy.html'
 
     class PropertySpecifiedTemplateTable(tables.Table):
         name = tables.Column()
 
     table = PropertySpecifiedTemplateTable([])
-    table.template = "dummy.html"
-    assert table.template == "dummy.html"
+    table.template = 'dummy.html'
+    assert table.template == 'dummy.html'
 
     class DefaultTable(tables.Table):
         pass
 
     table = DefaultTable([])
-    assert table.template == "django_tables2/table.html"
+    assert table.template == 'django_tables2/table.html'
 
 
 def test_template_in_meta_class_declaration_should_be_honored():
@@ -562,11 +563,11 @@ def test_template_in_meta_class_declaration_should_be_honored():
         name = tables.Column()
 
         class Meta:
-            template = "dummy.html"
+            template = 'dummy.html'
 
     table = MetaDeclarationSpecifiedTemplateTable([])
-    assert table.template == "dummy.html"
-    assert table.as_html(request) == "dummy template contents\n"
+    assert table.template == 'dummy.html'
+    assert table.as_html(request) == 'dummy template contents\n'
 
 
 def test_should_support_rendering_multiple_times():
@@ -580,13 +581,13 @@ def test_should_support_rendering_multiple_times():
 
 def test_column_defaults_are_honored():
     class Table(tables.Table):
-        name = tables.Column(default="abcd")
+        name = tables.Column(default='abcd')
 
         class Meta:
-            default = "efgh"
+            default = 'efgh'
 
-    table = Table([{}], default="ijkl")
-    assert table.rows[0]['name'] == "abcd"
+    table = Table([{}], default='ijkl')
+    assert table.rows[0].get_cell('name') == 'abcd'
 
 
 def test_table_meta_defaults_are_honored():
@@ -594,22 +595,22 @@ def test_table_meta_defaults_are_honored():
         name = tables.Column()
 
         class Meta:
-            default = "abcd"
+            default = 'abcd'
 
     table = Table([{}])
-    assert table.rows[0]['name'] == "abcd"
+    assert table.rows[0].get_cell('name') == 'abcd'
 
 
 def test_table_defaults_are_honored():
     class Table(tables.Table):
         name = tables.Column()
 
-    table = Table([{}], default="abcd")
-    assert table.rows[0]['name'] == "abcd"
+    table = Table([{}], default='abcd')
+    assert table.rows[0].get_cell('name') == 'abcd'
 
-    table = Table([{}], default="abcd")
-    table.default = "efgh"
-    assert table.rows[0]['name'] == "efgh"
+    table = Table([{}], default='abcd')
+    table.default = 'efgh'
+    assert table.rows[0].get_cell('name') == 'efgh'
 
 
 def test_list_table_data_supports_ordering():
@@ -617,11 +618,58 @@ def test_list_table_data_supports_ordering():
         name = tables.Column()
 
     data = [
-        {"name": "Bradley"},
-        {"name": "Davina"},
+        {'name': 'Bradley'},
+        {'name': 'Davina'},
     ]
 
     table = Table(data)
-    assert table.rows[0]["name"] == "Bradley"
-    table.order_by = "-name"
-    assert table.rows[0]["name"] == "Davina"
+    assert table.rows[0].get_cell('name') == 'Bradley'
+    table.order_by = '-name'
+    assert table.rows[0].get_cell('name') == 'Davina'
+
+
+def test_sorting_non_database_data():
+    class Table(tables.Table):
+        name = tables.Column()
+        country = tables.Column()
+
+    data = [
+        {'name': 'Adrian', 'country': 'Australia'},
+        {'name': 'Adrian', 'country': 'Brazil'},
+        {'name': 'Audrey', 'country': 'Chile'},
+        {'name': 'Bassie', 'country': 'Belgium'},
+    ]
+    table = Table(data, order_by=('-name', '-country'))
+
+    assert table.rows[0].get_cell('name') == 'Bassie'
+    assert table.rows[1].get_cell('name') == 'Audrey'
+    assert table.rows[2].get_cell('name') == 'Adrian'
+    assert table.rows[2].get_cell('country') == 'Brazil'
+    assert table.rows[3].get_cell('name') == 'Adrian'
+    assert table.rows[3].get_cell('country') == 'Australia'
+
+
+def test_row_attrs():
+    class Table(tables.Table):
+        alpha = tables.Column()
+        beta = tables.Column()
+
+    table = Table(MEMORY_DATA, row_attrs={
+        'class': lambda record: 'row-id-{}'.format(record['i']),
+    })
+
+    assert table.rows[0].attrs == {'class': 'row-id-2 even'}
+
+
+def test_row_attrs_in_meta():
+    class Table(tables.Table):
+        alpha = tables.Column()
+        beta = tables.Column()
+
+        class Meta:
+            row_attrs = {
+                'class': lambda record: 'row-id-{}'.format(record['i']),
+            }
+
+    table = Table(MEMORY_DATA)
+    assert table.rows[0].attrs == {'class': 'row-id-2 even'}
